@@ -13,7 +13,7 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union
+from typing import Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -69,7 +69,7 @@ __all__ = ("MemoryDBClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -129,7 +129,7 @@ class Exceptions:
 
 class MemoryDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html)
     """
 
@@ -142,12 +142,12 @@ class MemoryDBClient(BaseClient):
         """
 
     def batch_update_cluster(
-        self, *, ClusterNames: List[str], ServiceUpdate: "ServiceUpdateRequestTypeDef" = None
+        self, *, ClusterNames: Sequence[str], ServiceUpdate: "ServiceUpdateRequestTypeDef" = None
     ) -> BatchUpdateClusterResponseTypeDef:
         """
         Apply the service update to a list of clusters supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#batch_update_cluster)
         """
 
@@ -155,7 +155,7 @@ class MemoryDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#can_paginate)
         """
 
@@ -166,22 +166,22 @@ class MemoryDBClient(BaseClient):
         TargetSnapshotName: str,
         TargetBucket: str = None,
         KmsKeyId: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CopySnapshotResponseTypeDef:
         """
         Makes a copy of an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#copy_snapshot)
         """
 
     def create_acl(
-        self, *, ACLName: str, UserNames: List[str] = None, Tags: List["TagTypeDef"] = None
+        self, *, ACLName: str, UserNames: Sequence[str] = None, Tags: Sequence["TagTypeDef"] = None
     ) -> CreateACLResponseTypeDef:
         """
         Creates an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_acl)
         """
 
@@ -196,16 +196,16 @@ class MemoryDBClient(BaseClient):
         NumShards: int = None,
         NumReplicasPerShard: int = None,
         SubnetGroupName: str = None,
-        SecurityGroupIds: List[str] = None,
+        SecurityGroupIds: Sequence[str] = None,
         MaintenanceWindow: str = None,
         Port: int = None,
         SnsTopicArn: str = None,
         TLSEnabled: bool = None,
         KmsKeyId: str = None,
-        SnapshotArns: List[str] = None,
+        SnapshotArns: Sequence[str] = None,
         SnapshotName: str = None,
         SnapshotRetentionLimit: int = None,
-        Tags: List["TagTypeDef"] = None,
+        Tags: Sequence["TagTypeDef"] = None,
         SnapshotWindow: str = None,
         EngineVersion: str = None,
         AutoMinorVersionUpgrade: bool = None
@@ -213,7 +213,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_cluster)
         """
 
@@ -223,12 +223,12 @@ class MemoryDBClient(BaseClient):
         ParameterGroupName: str,
         Family: str,
         Description: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateParameterGroupResponseTypeDef:
         """
         Creates a new MemoryDB parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_parameter_group)
         """
 
@@ -238,12 +238,12 @@ class MemoryDBClient(BaseClient):
         ClusterName: str,
         SnapshotName: str,
         KmsKeyId: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateSnapshotResponseTypeDef:
         """
         Creates a copy of an entire cluster at a specific moment in time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_snapshot)
         """
 
@@ -251,14 +251,14 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         SubnetGroupName: str,
-        SubnetIds: List[str],
+        SubnetIds: Sequence[str],
         Description: str = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateSubnetGroupResponseTypeDef:
         """
         Creates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_subnet_group)
         """
 
@@ -268,12 +268,12 @@ class MemoryDBClient(BaseClient):
         UserName: str,
         AuthenticationMode: "AuthenticationModeTypeDef",
         AccessString: str,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> CreateUserResponseTypeDef:
         """
         Creates a MemoryDB user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_user)
         """
 
@@ -281,7 +281,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_acl)
         """
 
@@ -291,7 +291,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_cluster)
         """
 
@@ -301,7 +301,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes the specified parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_parameter_group)
         """
 
@@ -309,7 +309,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_snapshot)
         """
 
@@ -317,7 +317,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_subnet_group)
         """
 
@@ -325,7 +325,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_user)
         """
 
@@ -338,7 +338,7 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.describe_acls( ACLName='string',
         MaxResults=123, NextToken='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_acls)
         """
 
@@ -354,7 +354,7 @@ class MemoryDBClient(BaseClient):
         Returns information about all provisioned clusters if no cluster identifier is
         specified, or about a specific cluster if a cluster name is supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_clusters)
         """
 
@@ -370,7 +370,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of the available Redis engine versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_engine_versions)
         """
 
@@ -388,7 +388,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns events related to clusters, security groups, and parameter groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_events)
         """
 
@@ -398,7 +398,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of parameter group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameter_groups)
         """
 
@@ -408,7 +408,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns the detailed parameter list for a particular parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameters)
         """
 
@@ -416,8 +416,8 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         ServiceUpdateName: str = None,
-        ClusterNames: List[str] = None,
-        Status: List[ServiceUpdateStatusType] = None,
+        ClusterNames: Sequence[str] = None,
+        Status: Sequence[ServiceUpdateStatusType] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> DescribeServiceUpdatesResponseTypeDef:
@@ -427,7 +427,7 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.describe_service_updates(
         ServiceUpdateName='string', ClusterNames=[ ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_service_updates)
         """
 
@@ -444,7 +444,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns information about cluster snapshots.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_snapshots)
         """
 
@@ -454,7 +454,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of subnet group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_subnet_groups)
         """
 
@@ -462,14 +462,14 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         UserName: str = None,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         MaxResults: int = None,
         NextToken: str = None
     ) -> DescribeUsersResponseTypeDef:
         """
         Returns a list of users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_users)
         """
 
@@ -480,21 +480,21 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.failover_shard( ClusterName='string',
         ShardName='string' ).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#failover_shard)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#generate_presigned_url)
         """
 
@@ -505,7 +505,7 @@ class MemoryDBClient(BaseClient):
         Lists all available node types that you can scale to from your cluster's current
         node type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_allowed_node_type_updates)
         """
 
@@ -513,7 +513,7 @@ class MemoryDBClient(BaseClient):
         """
         Lists all tags currently on a named resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_tags)
         """
 
@@ -522,28 +522,28 @@ class MemoryDBClient(BaseClient):
         *,
         ParameterGroupName: str,
         AllParameters: bool = None,
-        ParameterNames: List[str] = None
+        ParameterNames: Sequence[str] = None
     ) -> ResetParameterGroupResponseTypeDef:
         """
         Modifies the parameters of a parameter group to the engine or system default
         value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#reset_parameter_group)
         """
 
     def tag_resource(
-        self, *, ResourceArn: str, Tags: List["TagTypeDef"]
+        self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]
     ) -> TagResourceResponseTypeDef:
         """
         A tag is a key-value pair where the key and value are case-sensitive.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#tag_resource)
         """
 
     def untag_resource(
-        self, *, ResourceArn: str, TagKeys: List[str]
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
     ) -> UntagResourceResponseTypeDef:
         """
         Use this operation to remove tags on a resource See also: `AWS API Documentation
@@ -551,17 +551,21 @@ class MemoryDBClient(BaseClient):
         **Request Syntax** response = client.untag_resource( ResourceArn='string',
         TagKeys=[ 'string', ] ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#untag_resource)
         """
 
     def update_acl(
-        self, *, ACLName: str, UserNamesToAdd: List[str] = None, UserNamesToRemove: List[str] = None
+        self,
+        *,
+        ACLName: str,
+        UserNamesToAdd: Sequence[str] = None,
+        UserNamesToRemove: Sequence[str] = None
     ) -> UpdateACLResponseTypeDef:
         """
         Changes the list of users that belong to the Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.update_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.update_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_acl)
         """
 
@@ -570,7 +574,7 @@ class MemoryDBClient(BaseClient):
         *,
         ClusterName: str,
         Description: str = None,
-        SecurityGroupIds: List[str] = None,
+        SecurityGroupIds: Sequence[str] = None,
         MaintenanceWindow: str = None,
         SnsTopicArn: str = None,
         SnsTopicStatus: str = None,
@@ -586,27 +590,27 @@ class MemoryDBClient(BaseClient):
         """
         Modifies the settings for a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_cluster)
         """
 
     def update_parameter_group(
-        self, *, ParameterGroupName: str, ParameterNameValues: List["ParameterNameValueTypeDef"]
+        self, *, ParameterGroupName: str, ParameterNameValues: Sequence["ParameterNameValueTypeDef"]
     ) -> UpdateParameterGroupResponseTypeDef:
         """
         Updates the parameters of a parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_parameter_group)
         """
 
     def update_subnet_group(
-        self, *, SubnetGroupName: str, Description: str = None, SubnetIds: List[str] = None
+        self, *, SubnetGroupName: str, Description: str = None, SubnetIds: Sequence[str] = None
     ) -> UpdateSubnetGroupResponseTypeDef:
         """
         Updates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_subnet_group)
         """
 
@@ -620,6 +624,6 @@ class MemoryDBClient(BaseClient):
         """
         Changes user password(s) and/or access string.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/memorydb.html#MemoryDB.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/memorydb.html#MemoryDB.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_user)
         """
